package com.xy.service;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.xy.dto.DeviceSimGoodsDto;
import com.xy.entity.DeviceSimGoods;
import com.xy.mapper.DeviceSimGoodsMapper;
import com.xy.utils.Emptys;
import com.xy.utils.MybatisPlusQuery;
import com.xy.utils.PageBean;
import com.xy.utils.R;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Service;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;

import java.util.List;

import static com.xy.utils.Beans.copy;
import static com.xy.utils.PlusBeans.toIPage;
import static com.xy.utils.PlusBeans.toPageBean;


/**
* <p>
* sim卡商品 服务实现类
* </p>
*
* @author 谭斌
* @since 2024-04-03
*/
@Service
@AllArgsConstructor
@Api(tags = "sim卡商品")
public class DeviceSimGoodsServiceImpl extends ServiceImpl<DeviceSimGoodsMapper, DeviceSimGoods> implements DeviceSimGoodsService {

    @Override
    @ApiOperation("对象查询")
    public R<DeviceSimGoodsDto.Vo> obj(@RequestBody DeviceSimGoodsDto.Vo vo) {
        DeviceSimGoodsDto.SelectList selectList = copy(DeviceSimGoodsDto.SelectList.class, vo);
        List<DeviceSimGoodsDto.Vo> list = list(selectList).getData();
        if(Emptys.check(list)) {
            return R.ok(list.get(0));
        }
        return R.ok();
    }

    @Override
    @ApiOperation("集合查询")
    public R<List<DeviceSimGoodsDto.Vo>> list(@RequestBody DeviceSimGoodsDto.SelectList selectList) {
        LambdaQueryWrapper<DeviceSimGoods> lambdaQueryWrapper = new MybatisPlusQuery().eqWrapper(selectList, DeviceSimGoods.class).build();
        List<DeviceSimGoods> list = list(lambdaQueryWrapper);
        return R.ok(copy(DeviceSimGoodsDto.Vo.class, list));
    }

    @PostMapping("page")
    @ApiOperation("分页查询")
    public R<PageBean<DeviceSimGoodsDto.Vo>> page(@RequestBody DeviceSimGoodsDto.Page page) {
        PageBean pageBean = page.getPage();
        LambdaQueryWrapper<DeviceSimGoods> lambdaQueryWrapper = new MybatisPlusQuery().eqWrapper(page, DeviceSimGoods.class).build();
        IPage<DeviceSimGoods> iPage = page(toIPage(pageBean), lambdaQueryWrapper);
        return R.ok(toPageBean(DeviceSimGoodsDto.Vo.class, iPage));
    }

    @PostMapping("save")
    @ApiOperation("添加")
    public R save(@RequestBody @Validated DeviceSimGoodsDto.Save save) {
        DeviceSimGoods saveInfo = copy(DeviceSimGoods.class, save);
        save(saveInfo);
        return R.ok();
    }

    @PostMapping("update")
    @ApiOperation("修改")
    public R update(@RequestBody @Validated DeviceSimGoodsDto.Update update) {
        DeviceSimGoods updateInfo = copy(DeviceSimGoods.class, update);
        updateById(updateInfo);
        return R.ok();
    }
}